==> llvm-19.1.7-2.gpkg.tar: image/usr/lib/llvm/19/lib/cmake/llvm/LLVMExports-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "LLVMDemangle" for configuration "RelWithDebInfo"
set_property(TARGET LLVMDemangle APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LLVMDemangle PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLLVMDemangle.a"
  )

list(APPEND _cmake_import_check_targets LLVMDemangle )
list(APPEND _cmake_import_check_files_for_LLVMDemangle "${_IMPORT_PREFIX}/lib/libLLVMDemangle.a" )

# Import target "LLVMSupport" for configuration "RelWithDebInfo"
set_property(TARGET LLVMSupport APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LLVMSupport PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "C;CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLLVMSupport.a"
  )

list(APPEND _cmake_import_check_targets LLVMSupport )
list(APPEND _cmake_import_check_files_for_LLVMSupport "${_IMPORT_PREFIX}/lib/libLLVMSupport.a" )

# Import target "LLVMTableGen" for configuration "RelWithDebInfo"
set_property(TARGET LLVMTableGen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LLVMTableGen PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLLVMTableGen.a"
  )

list(APPEND _cmake_import_check_targets LLVMTableGen )
list(APPEND _cmake_import_check_files_for_LLVMTableGen "${_IMPORT_PREFIX}/lib/libLLVMTableGen.a" )

# Import target "LLVMTestingAnnotations" for configuration "RelWithDebInfo"
set_property(TARGET LLVMTestingAnnotations APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LLVMTestingAnnotations PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLLVMTestingAnnotations.a"
  )

list(APPEND _cmake_import_check_targets LLVMTestingAnnotations )
list(APPEND _cmake_import_check_files_for_LLVMTestingAnnotations "${_IMPORT_PREFIX}/lib/libLLVMTestingAnnotations.a" )

# Import target "LLVMTestingSupport" for configuration "RelWithDebInfo"
set_property(TARGET LLVMTestingSupport APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LLVMTestingSupport PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLLVMTestingSupport.a"
  )

list(APPEND _cmake_import_check_targets LLVMTestingSupport )
list(APPEND _cmake_import_check_files_for_LLVMTestingSupport "${_IMPORT_PREFIX}/lib/libLLVMTestingSupport.a" )

# Import target "llvm_gtest" for configuration "RelWithDebInfo"
set_property(TARGET llvm_gtest APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(llvm_gtest PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "LLVM"
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libllvm_gtest.a"
  )

list(APPEND _cmake_import_check_targets llvm_gtest )
list(APPEND _cmake_import_check_files_for_llvm_gtest "${_IMPORT_PREFIX}/lib/libllvm_gtest.a" )

# Import target "llvm_gtest_main" for configuration "RelWithDebInfo"
set_property(TARGET llvm_gtest_main APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(llvm_gtest_main PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "LLVM"
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libllvm_gtest_main.a"
  )

list(APPEND _cmake_import_check_targets llvm_gtest_main )
list(APPEND _cmake_import_check_files_for_llvm_gtest_main "${_IMPORT_PREFIX}/lib/libllvm_gtest_main.a" )

# Import target "LTO" for configuration "RelWithDebInfo"
set_property(TARGET LTO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LTO PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLTO.so.19.1+libcxx"
  IMPORTED_SONAME_RELWITHDEBINFO "libLTO.so.19.1+libcxx"
  )

list(APPEND _cmake_import_check_targets LTO )
list(APPEND _cmake_import_check_files_for_LTO "${_IMPORT_PREFIX}/lib/libLTO.so.19.1+libcxx" )

# Import target "llvm-config" for configuration "RelWithDebInfo"
set_property(TARGET llvm-config APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(llvm-config PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/llvm-config"
  )

list(APPEND _cmake_import_check_targets llvm-config )
list(APPEND _cmake_import_check_files_for_llvm-config "${_IMPORT_PREFIX}/bin/llvm-config" )

# Import target "LLVM" for configuration "RelWithDebInfo"
set_property(TARGET LLVM APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LLVM PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLLVM.so.19.1+libcxx"
  IMPORTED_SONAME_RELWITHDEBINFO "libLLVM.so.19.1+libcxx"
  )

list(APPEND _cmake_import_check_targets LLVM )
list(APPEND _cmake_import_check_files_for_LLVM "${_IMPORT_PREFIX}/lib/libLLVM.so.19.1+libcxx" )

# Import target "Remarks" for configuration "RelWithDebInfo"
set_property(TARGET Remarks APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Remarks PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libRemarks.so.19.1+libcxx"
  IMPORTED_SONAME_RELWITHDEBINFO "libRemarks.so.19.1+libcxx"
  )

list(APPEND _cmake_import_check_targets Remarks )
list(APPEND _cmake_import_check_files_for_Remarks "${_IMPORT_PREFIX}/lib/libRemarks.so.19.1+libcxx" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> llvm-19.1.7-18.gpkg.tar: image/usr/lib/llvm/19/lib/cmake/llvm/LLVMExports-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "LLVMDemangle" for configuration "RelWithDebInfo"
set_property(TARGET LLVMDemangle APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LLVMDemangle PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLLVMDemangle.a"
  )

list(APPEND _cmake_import_check_targets LLVMDemangle )
list(APPEND _cmake_import_check_files_for_LLVMDemangle "${_IMPORT_PREFIX}/lib/libLLVMDemangle.a" )

# Import target "LLVMSupport" for configuration "RelWithDebInfo"
set_property(TARGET LLVMSupport APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LLVMSupport PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "C;CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLLVMSupport.a"
  )

list(APPEND _cmake_import_check_targets LLVMSupport )
list(APPEND _cmake_import_check_files_for_LLVMSupport "${_IMPORT_PREFIX}/lib/libLLVMSupport.a" )

# Import target "LLVMTableGen" for configuration "RelWithDebInfo"
set_property(TARGET LLVMTableGen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LLVMTableGen PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLLVMTableGen.a"
  )

list(APPEND _cmake_import_check_targets LLVMTableGen )
list(APPEND _cmake_import_check_files_for_LLVMTableGen "${_IMPORT_PREFIX}/lib/libLLVMTableGen.a" )

# Import target "LLVMTestingAnnotations" for configuration "RelWithDebInfo"
set_property(TARGET LLVMTestingAnnotations APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LLVMTestingAnnotations PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLLVMTestingAnnotations.a"
  )

list(APPEND _cmake_import_check_targets LLVMTestingAnnotations )
list(APPEND _cmake_import_check_files_for_LLVMTestingAnnotations "${_IMPORT_PREFIX}/lib/libLLVMTestingAnnotations.a" )

# Import target "LLVMTestingSupport" for configuration "RelWithDebInfo"
set_property(TARGET LLVMTestingSupport APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LLVMTestingSupport PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLLVMTestingSupport.a"
  )

list(APPEND _cmake_import_check_targets LLVMTestingSupport )
list(APPEND _cmake_import_check_files_for_LLVMTestingSupport "${_IMPORT_PREFIX}/lib/libLLVMTestingSupport.a" )

# Import target "llvm_gtest" for configuration "RelWithDebInfo"
set_property(TARGET llvm_gtest APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(llvm_gtest PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "LLVM"
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libllvm_gtest.a"
  )

list(APPEND _cmake_import_check_targets llvm_gtest )
list(APPEND _cmake_import_check_files_for_llvm_gtest "${_IMPORT_PREFIX}/lib/libllvm_gtest.a" )

# Import target "llvm_gtest_main" for configuration "RelWithDebInfo"
set_property(TARGET llvm_gtest_main APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(llvm_gtest_main PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "LLVM"
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libllvm_gtest_main.a"
  )

list(APPEND _cmake_import_check_targets llvm_gtest_main )
list(APPEND _cmake_import_check_files_for_llvm_gtest_main "${_IMPORT_PREFIX}/lib/libllvm_gtest_main.a" )

# Import target "LTO" for configuration "RelWithDebInfo"
set_property(TARGET LTO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LTO PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLTO.so.19.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libLTO.so.19.1"
  )

list(APPEND _cmake_import_check_targets LTO )
list(APPEND _cmake_import_check_files_for_LTO "${_IMPORT_PREFIX}/lib/libLTO.so.19.1" )

# Import target "llvm-config" for configuration "RelWithDebInfo"
set_property(TARGET llvm-config APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(llvm-config PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/llvm-config"
  )

list(APPEND _cmake_import_check_targets llvm-config )
list(APPEND _cmake_import_check_files_for_llvm-config "${_IMPORT_PREFIX}/bin/llvm-config" )

# Import target "LLVM" for configuration "RelWithDebInfo"
set_property(TARGET LLVM APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(LLVM PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libLLVM.so.19.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libLLVM.so.19.1"
  )

list(APPEND _cmake_import_check_targets LLVM )
list(APPEND _cmake_import_check_files_for_LLVM "${_IMPORT_PREFIX}/lib/libLLVM.so.19.1" )

# Import target "Remarks" for configuration "RelWithDebInfo"
set_property(TARGET Remarks APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Remarks PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libRemarks.so.19.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libRemarks.so.19.1"
  )

list(APPEND _cmake_import_check_targets Remarks )
list(APPEND _cmake_import_check_files_for_Remarks "${_IMPORT_PREFIX}/lib/libRemarks.so.19.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
